require "./version.rb"

version = $*[0]
File.open("version.rb","w"){|f| f.puts 'Version = %p' % version } if version

`rm -r ../site/iogii-#{version}` if Dir["../site/iogii-#{version}"] if version

`rm prog.iog input.txt test.hs iogii 2>&1`

`cd ../site; mkdir iogii-#{version}; cp -r ../src iogii-#{version}/src; tar -czf iogii-#{version}.tgz iogii-#{version}; rm -r iogii-#{version}` if version

`ruby web/mk1file.rb > iogii && chmod +x iogii`
`cp iogii ../site/iogii-#{version}` if version

File.open("version.rb","w"){|f| f.puts 'Version = "%s"' % version } if version

File.open("version.rb","w"){|f| f.puts 'Version = "%s+ (unstable)"' % version } if !version && !Version["unstable"]

if version
  puts 'release checklist
-----------------
test/all
ruby ../run_programs.rb
ruby ../run_programs_hs.rb
ruby test/fuzz_test.rb
ruby test/fuzz_test_hs.rb
ruby test/test_auto_parse.rb
clean files manually (ls -lth)
update docs/source.md page
ruby web/release 1.1   (put version here)
ruby web/generate.rb
view quickref/site
test online interpreter
check version number in quickref/#!iogii/tgz/online interpreter/haskell
ruby web/upload.rb
create snapshot, e.g. putweb golfscript.com public_html/iogii/0.2 ../site_uploaded/*'
end
